@@ -37,6 +37,13 @@ class Message:
             return False
         else:
             return bool(self.data.get('is_admin'))
+    @property
+    def is_bot(self):
+        """Является ли пользователь ботом."""
+        if not self.data.get('is_bot'):
+            return False
+        else:
+            return bool(self.data.get('is_bot'))
     
 class Post:
     def __init__(self, post: dict[str, str]):
@@ -122,6 +129,16 @@ class Bot:
                 return False
         else:
             return r.json().get("url")
+    def send_dm(self, username: str, content: str) -> bool:
+        """Отправка личных сообщений пользователям для передачи чувствительных данных.\nusername: ник пользователя для отправки ЛС.\ncontent: что ему над написать?\n`True` при успешной отправке. `False` при отсутствии пользователя в сети, или при неправильном токене."""
+        r = requests.post("https://florestmsgs-florestdev4185.amvera.io/api/bot/send_dm", params={"username":username, "content":content}, proxies=self.proxies, headers={"X-Bot-Token":self.token})
+        if r.status_code != 200:
+            if self.raise_on_status_code:
+                raise Exception(f"ОШИБКА! КОД: {r.status_code}. JSON: {r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+            else:
+                return False
+        else:
+            return True
     def get_blogs(self) -> list[Post]:
         """Список постов с `/blogs`."""
         r = requests.get("https://florestmsgs-florestdev4185.amvera.io/api/bot/get_blogs", headers={"X-Bot-Token":self.token}, proxies=self.proxies)
@@ -242,6 +259,26 @@ class AsyncBot:
             print(f"Ошибка клиента aiohttp: {e}")
             return False
     
+    async def send_dm(self, username: str, content: str) -> bool:
+        """Отправка личных сообщений пользователям для передачи чувствительных данных.\nusername: ник пользователя для отправки ЛС.\ncontent: что ему над написать?\n`True` при успешной отправке. `False` при отсутствии пользователя в сети, или при неправильном токене."""
+        url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/send_dm"
+        params = {"username":username, "content":content}
+        headers = {"X-Bot-Token": self.token}
+
+        try:
+            async with aiohttp.ClientSession() as session:
+                async with session.post(url, params=params, proxy=self.proxies, headers=headers) as r:
+                    if r.status != 200:
+                        if self.raise_on_status_code:
+                            raise Exception(f"ОШИБКА! КОД: {r.status}. JSON: {await r.json()}. ПРОВЕРЬТЕ ТОКЕН И ПРАВИЛЬНОСТЬ УКАЗАННЫХ ПАРАМЕТРОВ!!!")
+                        else:
+                            return False
+                    else:
+                        return True
+        except aiohttp.ClientError as e:
+            print(f"Ошибка клиента aiohttp: {e}")
+            return False
+
     async def get_blogs(self) -> list[Post]:
         """Асинхронный список постов с `/blogs`."""
         url = f"https://florestmsgs-florestdev4185.amvera.io/api/bot/get_blogs"
